==> scala-k8s-objects_sjs1_2.12-0.3.0-sources.jar: io/k8s/api/core/v1/AzureDiskVolumeSource.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** AzureDisk represents an Azure Data Disk mount on the host and bind mount to the pod. */
final case class AzureDiskVolumeSource(
  diskURI : String,
  diskName : String,
  readOnly : Option[Boolean] = None,
  fsType : Option[String] = None,
  cachingMode : Option[String] = None
) {

  /** Returns a new data with diskURI set to new value */
  def withDiskURI(value: String) : AzureDiskVolumeSource = copy(diskURI = value)
  /** transforms diskURI to result of function */
  def mapDiskURI(f: String => String) : AzureDiskVolumeSource = copy(diskURI = f(diskURI))

  /** Returns a new data with diskName set to new value */
  def withDiskName(value: String) : AzureDiskVolumeSource = copy(diskName = value)
  /** transforms diskName to result of function */
  def mapDiskName(f: String => String) : AzureDiskVolumeSource = copy(diskName = f(diskName))

  /** Returns a new data with readOnly set to new value */
  def withReadOnly(value: Boolean) : AzureDiskVolumeSource = copy(readOnly = Some(value))
  /** if readOnly has a value, transforms to the result of function*/
  def mapReadOnly(f: Boolean => Boolean) : AzureDiskVolumeSource = copy(readOnly = readOnly.map(f))

  /** Returns a new data with fsType set to new value */
  def withFsType(value: String) : AzureDiskVolumeSource = copy(fsType = Some(value))
  /** if fsType has a value, transforms to the result of function*/
  def mapFsType(f: String => String) : AzureDiskVolumeSource = copy(fsType = fsType.map(f))

  /** Returns a new data with cachingMode set to new value */
  def withCachingMode(value: String) : AzureDiskVolumeSource = copy(cachingMode = Some(value))
  /** if cachingMode has a value, transforms to the result of function*/
  def mapCachingMode(f: String => String) : AzureDiskVolumeSource = copy(cachingMode = cachingMode.map(f))
}

object AzureDiskVolumeSource {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.AzureDiskVolumeSource, T] = new Encoder[io.k8s.api.core.v1.AzureDiskVolumeSource, T] {
        def apply(o: io.k8s.api.core.v1.AzureDiskVolumeSource) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("diskURI", o.diskURI)
            .write("diskName", o.diskName)
            .write("readOnly", o.readOnly)
            .write("fsType", o.fsType)
            .write("cachingMode", o.cachingMode)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, AzureDiskVolumeSource] = new Decoder[T, AzureDiskVolumeSource] {
      def apply(t: T): Either[String, AzureDiskVolumeSource] = for {
          obj <- ObjectReader(t)
          diskURI <- obj.read[String]("diskURI")
          diskName <- obj.read[String]("diskName")
          readOnly <- obj.readOpt[Boolean]("readOnly")
          fsType <- obj.readOpt[String]("fsType")
          cachingMode <- obj.readOpt[String]("cachingMode")
      } yield AzureDiskVolumeSource (
          diskURI = diskURI,
          diskName = diskName,
          readOnly = readOnly,
          fsType = fsType,
          cachingMode = cachingMode
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.16.3-sources.jar: io/k8s/api/core/v1/AzureDiskVolumeSource.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** AzureDisk represents an Azure Data Disk mount on the host and bind mount to the pod. */
final case class AzureDiskVolumeSource(
  diskURI : String,
  diskName : String,
  readOnly : Option[Boolean] = None,
  fsType : Option[String] = None,
  kind : Option[String] = None,
  cachingMode : Option[String] = None
) {

  /** Returns a new data with diskURI set to new value */
  def withDiskURI(value: String) : AzureDiskVolumeSource = copy(diskURI = value)
  /** transforms diskURI to result of function */
  def mapDiskURI(f: String => String) : AzureDiskVolumeSource = copy(diskURI = f(diskURI))

  /** Returns a new data with diskName set to new value */
  def withDiskName(value: String) : AzureDiskVolumeSource = copy(diskName = value)
  /** transforms diskName to result of function */
  def mapDiskName(f: String => String) : AzureDiskVolumeSource = copy(diskName = f(diskName))

  /** Returns a new data with readOnly set to new value */
  def withReadOnly(value: Boolean) : AzureDiskVolumeSource = copy(readOnly = Some(value))
  /** if readOnly has a value, transforms to the result of function*/
  def mapReadOnly(f: Boolean => Boolean) : AzureDiskVolumeSource = copy(readOnly = readOnly.map(f))

  /** Returns a new data with fsType set to new value */
  def withFsType(value: String) : AzureDiskVolumeSource = copy(fsType = Some(value))
  /** if fsType has a value, transforms to the result of function*/
  def mapFsType(f: String => String) : AzureDiskVolumeSource = copy(fsType = fsType.map(f))

  /** Returns a new data with kind set to new value */
  def withKind(value: String) : AzureDiskVolumeSource = copy(kind = Some(value))
  /** if kind has a value, transforms to the result of function*/
  def mapKind(f: String => String) : AzureDiskVolumeSource = copy(kind = kind.map(f))

  /** Returns a new data with cachingMode set to new value */
  def withCachingMode(value: String) : AzureDiskVolumeSource = copy(cachingMode = Some(value))
  /** if cachingMode has a value, transforms to the result of function*/
  def mapCachingMode(f: String => String) : AzureDiskVolumeSource = copy(cachingMode = cachingMode.map(f))
}

object AzureDiskVolumeSource {

    implicit val encoder : Encoder[io.k8s.api.core.v1.AzureDiskVolumeSource] = new Encoder[io.k8s.api.core.v1.AzureDiskVolumeSource] {
        def apply[T : Builder](o: io.k8s.api.core.v1.AzureDiskVolumeSource) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("diskURI", o.diskURI)
            .write("diskName", o.diskName)
            .write("readOnly", o.readOnly)
            .write("fsType", o.fsType)
            .write("kind", o.kind)
            .write("cachingMode", o.cachingMode)
            .build
        }
    }

    implicit val decoder: Decoder[AzureDiskVolumeSource] = new Decoder[AzureDiskVolumeSource] {
      def apply[T : Reader](t: T): Either[String, AzureDiskVolumeSource] = for {
          obj <- ObjectReader(t)
          diskURI <- obj.read[String]("diskURI")
          diskName <- obj.read[String]("diskName")
          readOnly <- obj.readOpt[Boolean]("readOnly")
          fsType <- obj.readOpt[String]("fsType")
          kind <- obj.readOpt[String]("kind")
          cachingMode <- obj.readOpt[String]("cachingMode")
      } yield AzureDiskVolumeSource (
          diskURI = diskURI,
          diskName = diskName,
          readOnly = readOnly,
          fsType = fsType,
          kind = kind,
          cachingMode = cachingMode
        )
    }
}
